package javax.security.cert;

import java.security.AccessController;
import java.security.Security;
import java.security.PrivilegedAction;
import java.security.Principal;
import java.math.BigInteger;
import java.util.Date;
import java.lang.reflect.InvocationTargetException;
import java.io.InputStream;

public abstract class X509Certificate extends Certificate
{
    private static final String X509_PROVIDER = "cert.provider.x509v1";
    private static String X509Provider;
    
    public X509Certificate() {
    }
    
    public static final X509Certificate getInstance(InputStream inputStream) throws CertificateException {
        return getInst(inputStream);
    }
    
    public static final X509Certificate getInstance(byte[] array) throws CertificateException {
        return getInst(array);
    }
    
    private static final X509Certificate getInst(Object o) throws CertificateException {
        String x509Provider = X509Certificate.X509Provider;
        if (x509Provider == null || x509Provider.length() == 0) {
            x509Provider = "com.sun.security.cert.internal.x509.X509V1CertImpl";
        }
        try {
            Class[] parameterTypes;
            if ((o instanceof InputStream)) {
                parameterTypes = new Class[] { InputStream.class };
            }
            else if ((o instanceof byte[])) {
                parameterTypes = new Class[] { o.getClass() };
            }
            else {
                throw new CertificateException("Unsupported argument type");
            }
            return (X509Certificate)Class.forName(x509Provider).getConstructor(parameterTypes).newInstance(new Object[] { o });
        }
        catch (ClassNotFoundException obj) {
            throw new CertificateException("Could not find class: " + obj);
        }
        catch (IllegalAccessException obj2) {
            throw new CertificateException("Could not access class: " + obj2);
        }
        catch (InstantiationException obj3) {
            throw new CertificateException("Problems instantiating: " + obj3);
        }
        catch (InvocationTargetException ex) {
            throw new CertificateException("InvocationTargetException: " + ex.getTargetException());
        }
        catch (NoSuchMethodException ex2) {
            throw new CertificateException("Could not find class method: " + ex2.getMessage());
        }
    }
    
    public abstract void checkValidity() throws CertificateExpiredException, CertificateNotYetValidException;
    
    public abstract void checkValidity(Date p0) throws CertificateExpiredException, CertificateNotYetValidException;
    
    public abstract int getVersion();
    
    public abstract BigInteger getSerialNumber();
    
    public abstract Principal getIssuerDN();
    
    public abstract Principal getSubjectDN();
    
    public abstract Date getNotBefore();
    
    public abstract Date getNotAfter();
    
    public abstract String getSigAlgName();
    
    public abstract String getSigAlgOID();
    
    public abstract byte[] getSigAlgParams();
    
    static {
        X509Certificate.X509Provider = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return Security.getProperty("cert.provider.x509v1");
            }
        });
    }
}
